@@ -2,7 +2,7 @@
 A TiddlyWeb plugin providing a multi-user TiddlyWiki environment.
 """
 
-__version__ = '0.22.1'
+__version__ = '0.23.0'
 
 
 def init(config):
@@ -13,6 +13,7 @@ def init(config):
     import tiddlywebplugins.atom
     import tiddlywebplugins.differ
     import tiddlywebplugins.twimport
+    import tiddlywebplugins.console
     from tiddlyweb.util import merge_config
     from tiddlywebwiki.config import config as twwconfig
 
@@ -22,3 +23,4 @@ def init(config):
     tiddlywebplugins.atom.init(config)
     tiddlywebplugins.differ.init(config)
     tiddlywebplugins.twimport.init(config)
+    tiddlywebplugins.console.init(config)
